@@ -17,6 +17,14 @@ def main() -> None:
 
 
 # HTTP entry point for web clients
+def _get_http_runtime() -> tuple[int, str]:
+    """Return runtime configuration shared by HTTP transports."""
+
+    port = int(os.getenv("MCP_PORT", "8086"))
+    path = os.getenv("MCP_SECRET_PATH", "/mcp")
+    return port, path
+
+
 def main_web() -> None:
     """Run server over HTTP for web-capable MCP clients.
 
@@ -27,8 +35,7 @@ def main_web() -> None:
     - MCP_SECRET_PATH (optional, default: "/mcp")
     """
 
-    port = int(os.getenv("MCP_PORT", "8086"))
-    path = os.getenv("MCP_SECRET_PATH", "/mcp")
+    port, path = _get_http_runtime()
 
     mcp.run(
         transport="streamable-http",
@@ -38,5 +45,25 @@ def main_web() -> None:
     )
 
 
+def main_sse() -> None:
+    """Run server using Server-Sent Events transport for MCP clients.
+
+    Environment:
+    - HOMEASSISTANT_URL (required)
+    - HOMEASSISTANT_TOKEN (required)
+    - MCP_PORT (optional, default: 8086)
+    - MCP_SECRET_PATH (optional, default: "/mcp")
+    """
+
+    port, path = _get_http_runtime()
+
+    mcp.run(
+        transport="sse",
+        host="0.0.0.0",
+        port=port,
+        path=path,
+    )
+
+
 if __name__ == "__main__":
     main()
